==> jei-1.20.1-fabric-15.20.0.123-sources.jar: mezz/jei/library/gui/recipes/layout/builder/IngredientAcceptorVoid.java <==
package mezz.jei.library.gui.recipes.layout.builder;

import mezz.jei.api.gui.builder.IIngredientAcceptor;
import mezz.jei.api.ingredients.IIngredientType;
import mezz.jei.api.ingredients.ITypedIngredient;
import net.minecraft.class_2487;
import net.minecraft.class_3611;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Optional;

public class IngredientAcceptorVoid implements IIngredientAcceptor<IngredientAcceptorVoid> {
	public static final IngredientAcceptorVoid INSTANCE = new IngredientAcceptorVoid();

	private IngredientAcceptorVoid() {}

	@Override
	public IngredientAcceptorVoid addIngredientsUnsafe(List<?> ingredients) {
		return this;
	}

	@Override
	public <I> IngredientAcceptorVoid addIngredients(IIngredientType<I> ingredientType, List<@Nullable I> ingredients) {
		return this;
	}

	@Override
	public <I> IngredientAcceptorVoid addIngredient(IIngredientType<I> ingredientType, I ingredient) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addTypedIngredients(List<ITypedIngredient<?>> ingredients) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addOptionalTypedIngredients(List<Optional<ITypedIngredient<?>>> ingredients) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addFluidStack(class_3611 fluid) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addFluidStack(class_3611 fluid, long amount) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addFluidStack(class_3611 fluid, long amount, class_2487 tag) {
		return this;
	}
}

==> jei-1.21.1-fabric-19.25.1.333-sources.jar: mezz/jei/library/gui/recipes/layout/builder/IngredientAcceptorVoid.java <==
package mezz.jei.library.gui.recipes.layout.builder;

import mezz.jei.api.gui.builder.IIngredientAcceptor;
import mezz.jei.api.ingredients.IIngredientType;
import mezz.jei.api.ingredients.ITypedIngredient;
import net.minecraft.class_3611;
import net.minecraft.class_9326;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Optional;

public class IngredientAcceptorVoid implements IIngredientAcceptor<IngredientAcceptorVoid> {
	public static final IngredientAcceptorVoid INSTANCE = new IngredientAcceptorVoid();

	private IngredientAcceptorVoid() {}

	@Override
	public IngredientAcceptorVoid addIngredientsUnsafe(List<?> ingredients) {
		return this;
	}

	@Override
	public <I> IngredientAcceptorVoid addIngredients(IIngredientType<I> ingredientType, List<@Nullable I> ingredients) {
		return this;
	}

	@Override
	public <I> IngredientAcceptorVoid addIngredient(IIngredientType<I> ingredientType, I ingredient) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addTypedIngredients(List<ITypedIngredient<?>> ingredients) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addOptionalTypedIngredients(List<Optional<ITypedIngredient<?>>> ingredients) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addFluidStack(class_3611 fluid) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addFluidStack(class_3611 fluid, long amount) {
		return this;
	}

	@Override
	public IngredientAcceptorVoid addFluidStack(class_3611 fluid, long amount, class_9326 componentPatch) {
		return this;
	}
}
